# -*- coding: utf-8 -*-
# Copyright (c) 2009-2012 Michael Howitz
# See also LICENSE.txt

import icemac.ab.importer.importer
import icemac.ab.importer.interfaces
import zope.component


@zope.component.adapter(
    icemac.addressbook.addressbook.AddressBookCreated)
def install_importer(event):
    "Install the importer in the newly created addressbook."
    address_book = event.address_book
    icemac.addressbook.addressbook.create_and_register(
        address_book, 'importer', icemac.ab.importer.importer.Importer,
        icemac.ab.importer.interfaces.IImporter)



# Copyright (c) 2008-2012 Michael Howitz
# See also LICENSE.txt
# $Id: testing.py 1454 2012-01-05 10:36:41Z icemac $

import icemac.ab.importer.browser
import icemac.addressbook.testing
import plone.testing.zca


IMPORTER_ZCML_LAYER = plone.testing.zca.ZCMLSandbox(
    name="ImporterZCML", filename="ftesting.zcml",
    package=icemac.ab.importer.browser)


ImporterLayer = icemac.addressbook.testing._WSGITestBrowserLayer(
    bases=[icemac.addressbook.testing.WSGILayer(
        bases=[icemac.addressbook.testing._ZODBIsolatedTestLayer(
            bases=[icemac.addressbook.testing._ZODBLayer(
                bases=[icemac.addressbook.testing.ZCML_LAYER,
                       IMPORTER_ZCML_LAYER],
                name='ImporterZODBLayer')],
            name='ImporterZODBIsolatedTestLayer')],
        name='ImporterWSGILayer')],
    name='ImporterLayer')



# Copyright (c) 2008-2012 Michael Howitz
# See also LICENSE.txt

import icemac.ab.importer.install
import icemac.addressbook.addressbook
import icemac.addressbook.testing
import unittest2 as unittest


class TestInstall(unittest.TestCase,
                  icemac.addressbook.testing.InstallationAssertions):

    layer = icemac.addressbook.testing.ADDRESS_BOOK_FUNCTIONAL_LAYER

    def check_addressbook(self, ab):
        self.assertAttribute(
            ab, 'importer', icemac.ab.importer.interfaces.IImporter)

    def setUp(self):
        self.ab = self.layer['addressbook']

    def test_create(self):
        icemac.addressbook.addressbook.create_address_book_infrastructure(
            self.ab)
        icemac.ab.importer.install.install_importer(
            icemac.addressbook.addressbook.AddressBookCreated(self.ab))
        self.check_addressbook(self.ab)

    def test_recall_create(self):
        icemac.addressbook.addressbook.create_address_book_infrastructure(
            self.ab)
        event = icemac.addressbook.addressbook.AddressBookCreated(self.ab)
        icemac.ab.importer.install.install_importer(event)
        icemac.ab.importer.install.install_importer(event)
        self.check_addressbook(self.ab)
